#!/usr/bin/env bash
#
# Copyright 2016 - The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

TOOLS_DIR=$(realpath $(dirname $0))
LTP_ANDROID_DIR=$(realpath $TOOLS_DIR/..)
LTP_ROOT=$(realpath $LTP_ANDROID_DIR/..)
OUTPUT=$LTP_ROOT/Android.ltp.mk

echo "TOOLS_DIR: $TOOLS_DIR"
echo "LTP_ANDROID_DIR: $LTP_ANDROID_DIR"
echo "LTP_ROOT: $LTP_ROOT"
echo "OUTPUT: $OUTPUT"

if ! [ -f $LTP_ROOT/include/config.h ]; then
	echo "LTP has not been configured!"
	echo "Please run \"cd $LTP_ROOT; make autotools; ./configure\" first"
	exit 1
fi

echo "# This file autogenerated by $(basename $0)" > $OUTPUT
echo "" >> $OUTPUT

make -C $LTP_ROOT/testcases --dry-run 2> /dev/null |
	python $TOOLS_DIR/parse_ltp_make.py --ltp-root=$LTP_ROOT - |
	python $TOOLS_DIR/gen_android_mk.py --disabled-tests=$TOOLS_DIR/disabled_tests.txt - >> $OUTPUT

make -C $LTP_ROOT/testcases install --dry-run 2> /dev/null |
	python $TOOLS_DIR/parse_ltp_make_install.py --ltp-root=$LTP_ROOT - |
	python $TOOLS_DIR/gen_android_mk.py --disabled-tests=$TOOLS_DIR/disabled_tests.txt - >> $OUTPUT
